<?php
namespace Planejamento\Entities;

use Geral\Util\Ambiente;
use Geral\Util\DateUtil;
use \Geral\Util\NovoCodigo;
use \Geral\Entities\Filial;
use \Geral\Entities\Servico;

/**
 * @method \Planejamento\Entities\Cardadia findOneByNrorgAndCdfilialAndDtcardapioAndCdservfili($nrorg, $filial, $dtCardapio, $servico) static
 * @method \Planejamento\Entities\Cardadia[] findOneByExisteEfetivos()
 * @method \Planejamento\Entities\Cardadia findOneByNrcardapioAndCdfilialAndNrorg($nrcardapio, $cdfilial, $nrorg) static
 */
class Cardadia extends Base\Cardadia
{

    /** @var $compcard array */
    protected $compcards;

    /** @var $compcard Compcard */
    protected $compcard;

    public function insereCardadia($filial, $nrorg, $servico, $diaMes, $operador, $dataCardapio, $operInclusao){
        $dtAtual = DateUtil::getDataAtual();
        $dataCardapio = DateUtil::truncateData($dataCardapio);

        $cdCardadia = NovoCodigo::geraCodigo($nrorg, 'CARDAPIO'.$filial);

        /** @var $objFilial Filial */
        $objFilial = Filial::getObject(array('cdfilial' => $filial, 'nrorg' => $nrorg));
        /** @var $objServFili Servico */
        $objServFili = Servico::getObject(array('cdfilial' => $filial, 'nrorg' => $nrorg, 'cdservfili' => $servico));

        $this->setNrcardapio($cdCardadia);
        $this->setFilial($objFilial);
        $this->setServfili($objServFili);
        $this->setDtmescard($diaMes);
        $this->setCdoperador($operador);
        $this->setDtcardapio($dataCardapio);
        $this->setDtinclusao($dtAtual);
        $this->setDtultatu($dtAtual);
        $this->setCdoperinclusao($operInclusao);
        $this->setNrorginclusao($nrorg);

        $this->persist();

        return $this;
    }


    public static function consultaCardapioDataServico($nrorg, $filial, $dtCardapio, $servico){
        $objs = self::getObjectByWhere(
            'NRORG = ? AND CDFILIAL = ? AND DTCARDAPIO = ? AND CDSERVFILI = ?',
            array($nrorg, $filial, $dtCardapio, $servico)
        );

        return $objs;
    }


    public function atualizaCardapio($servico, $dtCardapio, $operAtual){
        $dtAtual = DateUtil::getDataAtual();
        if (is_object($dtCardapio) === false) {
            $dtCardapio = DateUtil::truncateData(
                DateUtil::getDataDeString($dtCardapio)
            );
        }

        $this->setCdservfili($servico);
        $this->setDtcardapio($dtCardapio);
        $this->setDtinclusao($dtAtual);
        $this->setCdoperinclusao($operAtual);

        $this->setDtultatu($dtAtual);
        $this->setNrorgultatu(Ambiente::getNrorg());
        $this->setCdoperinclusao($operAtual);

        $this->persist();

        return $this;
    }



    public function setChavesPrimarias($nrorg, $cdfilial) {
        $this->setNrorg($nrorg);
        $this->setCdfilial($cdfilial);
        $nrcardapio = NovoCodigo::geraCodigo($nrorg, 'CARDAPIO'.$cdfilial);
        $this->setNrcardapio($nrcardapio);
    }

    public function setQuantidadeComensaisEstimadas($qtcomesticar, $qtcliesticar, $qtfunesticar, $qtdoaesticar) {
        $this->setQtcomesticar($qtcomesticar);
        $this->setQtcliesticar($qtcliesticar);
        $this->setQtfunesticar($qtfunesticar);
        $this->setQtdoaesticar($qtdoaesticar);
    }

    /**
     * @return array|Compcard
     */
    public function getComposicoesDoCardapio() {
        if ($this->compcards === null) {
            $where = array($this->nrorg, $this->cdfilial, $this->nrcardapio);
            $this->compcards = Compcard::getObjectsByWhere('NRORG = ? AND CDFILIAL = ? AND NRCARDAPIO = ?', $where);
        }

        return $this->compcards;
    }

    /**
     * @param $nrseqpratcar
     * @return object|\Planejamento\Entities\Compcard
     */
    public function getComposicaoDoCardapio($nrseqpratcar) {
        $id = array(
            'nrorg' => $this->nrorg,
            'cdfilial' => $this->cdfilial,
            'nrcardapio' => $this->nrcardapio,
            'nrseqpratcar' => $nrseqpratcar
        );

        $compcard = Compcard::getObject($id);
        return $compcard;
    }

    public static function retornaCardadia($nrorg, $cdfilial, $cdservico, $dtcardapio) {
        /** @var $cardapioDoDia Cardadia */
        $cardapioDoDia = self::getObjectByWhere(
            'NRORG = ? AND CDFILIAL = ? AND CDSERVFILI = ? AND DTCARDAPIO = ?',
            array($nrorg, $cdfilial, $cdservico, $dtcardapio)
        );

        return $cardapioDoDia;
    }

    public function atualizaEfetivosPLanejamnto($refeicoesCliente, $funcionariosEfetivos, $doacoesEfetivas, $comensaisEfetivos, $dtultatu, $cdoperultatu, $nrorg){

        $this->setQtcliefetcar($refeicoesCliente);
        $this->setQtfunefetcar($funcionariosEfetivos);
        $this->setQtdoaefetcar($doacoesEfetivas);
        $this->setQtcomefetcar($comensaisEfetivos);
        $this->setDtultatu($dtultatu);
        $this->setCdoperultatu($cdoperultatu);
        $this->setNrorgultatu($nrorg);

        $this->persist();

        return $this;
    }

    public static function deleta($nrorg, $cdfilial, $nrcardapio)
    {
        try {
            $cardadia = Cardadia::getObjectByWhere(
                'NRORG = ? AND CDFILIAL = ? AND NRCARDAPIO = ?',
                array($nrorg, $cdfilial, $nrcardapio)
            );

            if ($cardadia instanceof Cardadia) {
                $connection = \Setforms2\Shared\Registry::getEntityManager();
                $connection->beginTransaction();

                $cardadia->delete();

                $connection->flush();
                $connection->commit();
            }

            return true;
        } catch (\Exception $e) {
            $connection->rollback();
            throw $e;
        }
    }

    public static function atualizaComensais(
        $nrorg, $cdfilial, $nrcardapio, $qtcomesticar, $qtcliesticar,
        $qtfunesticar, $qtdoaesticar, $qtestiturno1, $qtestiturno2,
        $qtestiturno3 = null, $qtestiturno4 = null
    )
    {
        try {
            $cardadia = Cardadia::getObjectByWhere(
                'NRORG = ? AND CDFILIAL = ? AND NRCARDAPIO = ?',
                array($nrorg, $cdfilial, $nrcardapio)
            );

            if ($cardadia instanceof Cardadia) {
                $connection = \Setforms2\Shared\Registry::getEntityManager();
                $connection->beginTransaction();

                $cardadia->setQtcomesticar($qtcomesticar);
                $cardadia->setQtcliesticar($qtcliesticar);
                $cardadia->setQtfunesticar($qtfunesticar);
                $cardadia->setQtdoaesticar($qtdoaesticar);
                $cardadia->setQtestiturno1($qtestiturno1);
                $cardadia->setQtestiturno2($qtestiturno2);
                $cardadia->setQtestiturno3($qtestiturno3);
                $cardadia->setQtestiturno4($qtestiturno4);
                $cardadia->setNrorgultatu($nrorg);
                $cardadia->setDtultatu(DateUtil::getDataAtual());
                $cardadia->setCdoperultatu(Ambiente::getCdoperador());
                $cardadia->persist();

                $connection->flush();
                $connection->commit();
            }

            return true;
        } catch (\Exception $e) {
            $connection->rollback();
            throw $e;
        }
    }

    public static function retornaData($data, $cdfilial, $nrorg){

        /** @var $cardapioDoDia Cardadia */

        $cardapioDoDia = Cardadia::getObjectByWhere('DTCARDAPIO = ?
        AND CDFILIAL = ? AND NRORG
        =? ',array($data, $cdfilial, $nrorg));

        return $cardapioDoDia;
    }

}