<?php
/**
 * Namespace Vendas\Entities
 *
 * PHP version 5
 *
 * @category Php
 * @package  Vendas\Entities
 * @author   andreteixeira <andre.teixeira@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
namespace Vendas\Entities;

/**
 * Class Subgrprodfil
 *
 * PHP version 5
 *
 * @category Php
 * @package  Vendas\Entities
 * @author   andreteixeira <andre.teixeira@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
class Subgrprodfil extends Base\Subgrprodfil
{

    /**
     * Seta os campos do Registro.
     *
     * @param String $nrorg           Organização
     * @param String $cdgrupprod      Código do Grupo
     * @param String $cdsubgrprod     Código do Subgrupo
     * @param String $cdfilisubgr     Código da Unidade
     * @param String $nrmaxitsubgr    Número Máximo
     * @param String $idcadsubgrfi    Cadastro de Unidade
     * @param String $idsubgrmatprima Matéria Prima
     * @param String $nrorginclusao   Organização Inclusao
     * @param String $cdoperinclusao  Operador Inclusao
     * @param String $dtinclusao      Data Inclusao
     * @param String $nrorgultatu     Organização
     * @param String $dtultatu        Data Atualização
     * @param String $cdoperultatu    Operador Atualização
     *
     * @return null
     */
    public static function setCamposRegistro (
        $nrorg, $cdgrupprod, $cdsubgrprod, $cdfilisubgr, $nrmaxitsubgr,
        $idcadsubgrfi, $idsubgrmatprima, $nrorginclusao, $cdoperinclusao,
        $dtinclusao, $nrorgultatu, $dtultatu, $cdoperultatu
    ) {
        $subgrprodfil = self::buscaRegistro(
            $nrorg, $cdgrupprod, $cdsubgrprod, $cdfilisubgr
        );

        if (!($subgrprodfil instanceof self)) {
            $subgrprodfil = new self();
            $subgrprodfil->setCdgrupprod($cdgrupprod);
            $subgrprodfil->setCdsubgrprod($cdsubgrprod);
            $subgrprodfil->setCdfilisubgr($cdfilisubgr);
            $subgrprodfil->setNrorg($nrorg);
            $subgrprodfil->setNrorginclusao($nrorginclusao);
            $subgrprodfil->setDtinclusao($dtinclusao);
            $subgrprodfil->setCdoperinclusao($cdoperinclusao);
        }

        $subgrprodfil->setNrmaxitsubgr($nrmaxitsubgr);
        $subgrprodfil->setIdcadsubgrfi($idcadsubgrfi);
        $subgrprodfil->setIdsubgrmatprima($idsubgrmatprima);
        $subgrprodfil->setNrorgultatu($nrorgultatu);
        $subgrprodfil->setDtultatu($dtultatu);
        $subgrprodfil->setCdoperultatu($cdoperultatu);
        $subgrprodfil->persist();
    }

    /**
     * Retorna um Registro
     *
     * @param String $nrorg       Organização
     * @param String $cdgrupprod  Código do Grupo
     * @param String $cdsubgrprod Código do Subgrupo
     * @param String $cdfilisubgr Código da Unidade
     *
     * @return bool.
     */
    public static function buscaRegistro (
        $nrorg, $cdgrupprod, $cdsubgrprod, $cdfilisubgr
    ) {
        return self::getObjectByWhere(
            "NRORG = ? AND CDGRUPPROD = ? AND CDSUBGRPROD = ? AND CDFILISUBGR = ?",
            array($nrorg, $cdgrupprod, $cdsubgrprod, $cdfilisubgr)
        );
    }

    /**
     * Exclui Todos os Subgrupos da Unidade
     *
     * @param String $nrorg       Organização
     * @param String $cdfilisubgr Código da Unidade
     *
     * @return null
     */
    public static function excluiRegistros (
        $nrorg, $cdfilisubgr
    ) {
        $regs = self::getObjectsByWhere(
            "NRORG = ? AND CDFILISUBGR = ?",
            array($nrorg, $cdfilisubgr)
        );

        if (is_array($regs)) {
            foreach ($regs as $reg) {
                if ($reg instanceof self) {
                    $reg->delete();
                }
            }
        }
    }

}